summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThomas Graf <tgraf@suug.ch>2011-03-24 12:59:57 +0100
committerThomas Graf <tgraf@suug.ch>2011-03-24 12:59:57 +0100
commit14fa557ba94a4243b5963ea137412c5e1204ecb5 (patch)
tree4c32438954b38dca84611bae036493241621dfef
parent9f1abddb1af5b94d5e82dd12e7fa8ebf18acfc64 (diff)
downloadlibnl-14fa557ba94a4243b5963ea137412c5e1204ecb5.tar.gz
Set default MTU to 1500
-rw-r--r--lib/route/tc.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/route/tc.c b/lib/route/tc.c
index e4faf92..56aa410 100644
--- a/lib/route/tc.c
+++ b/lib/route/tc.c
@@ -318,7 +318,7 @@ void rtnl_tc_set_mtu(struct rtnl_tc *tc, uint32_t mtu)
* Returns the MTU of a traffic control object which has been set via:
* -# User specified value set via rtnl_tc_set_mtu()
* -# Dervied from link set via rtnl_tc_set_link()
* -# Fall back to default: ethernet = 1600
*/
uint32_t rtnl_tc_get_mtu(struct rtnl_tc *tc)
{
@@ -327,7 +327,7 @@ uint32_t rtnl_tc_get_mtu(struct rtnl_tc *tc)
else if (tc->ce_mask & TCA_ATTR_LINK)
return tc->tc_link->l_mtu;
else
- return 1600; /* default to ethernet */
+ return 1500; /* default to ethernet */
}
/**
@@ -318,7 +318,7 @@ void rtnl_tc_set_mtu(struct rtnl_tc *tc, uint32_t mtu)
* -# User specified value set via rtnl_tc_set_mtu()
* -# Dervied from link set via rtnl_tc_set_link()
- * -# Fall back to default: ethernet = 1600
+ * -# Fall back to default: ethernet = 1500
*/
uint32_t rtnl_tc_get_mtu(struct rtnl_tc *tc)